pytilities.geometry.functions — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry.functions

`pytilities.geometry.functions.` `_get_vector_operator`(self, other)

  Get instance for operator thingy. discrete op vector = vector

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »